@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 'v0.2.0'; # VERSION
+our $VERSION = 'v0.2.1'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -15,48 +15,17 @@ with qw(
 
 use Business::CyberSource::Response;
 
-use XML::Compile::SOAP::WSS 0.12;
-
-use XML::Compile::WSDL11;
-use XML::Compile::SOAP11;
-use XML::Compile::Transport::SOAPHTTP;
-
 sub submit {
 	my $self = shift;
 
-    my $wss = XML::Compile::SOAP::WSS->new( version => '1.1' );
-
-    my $wsdl = XML::Compile::WSDL11->new( $self->cybs_wsdl->stringify );
-    $wsdl->importDefinitions( $self->cybs_xsd->stringify );
-
-    my $call = $wsdl->compileClient('runTransaction');
-
-    my $security = $wss->wsseBasicAuth( $self->username, $self->password );
-
-	my ( $answer, $trace ) = $call->(
-		wsse_Security         => $security,
-		merchantID            => $self->username,
-		merchantReferenceCode => $self->reference_code,
-		clientEnvironment     => $self->client_env,
-		clientLibrary         => $self->client_name,
-		clientLibraryVersion  => $self->client_version,
-		purchaseTotals => {
-			currency         => $self->currency,
-			grandTotalAmount => $self->total,
-		},
+	my $payload = {
 		ccAuthReversalService => {
 			run => 'true',
 			authRequestID => $self->request_id,
 		},
-	);
+	};
 
-	$self->trace( $trace );
-
-	if ( $answer->{Fault} ) {
-		croak 'SOAP Fault: ' . $answer->{Fault}->{faultstring};
-	}
-
-	my $r = $answer->{result};
+	my $r = $self->_build_request( $payload );
 
 	my $res;
 	if ( $r->{decision} eq 'ACCEPT' ) {
@@ -124,7 +93,7 @@ Business::CyberSource::Request::AuthReversal - CyberSource Reverse Authorization
 
 =head1 VERSION
 
-version v0.2.0
+version v0.2.1
 
 =head1 SYNOPSIS
 
